# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [v0.2.3] - 2026-03-07

- No changes

## [v0.2.2] - 2026-03-07

- No changes

## [v0.2.1] - 2026-03-07

- No changes

## [v0.1.0] - 2025-09-24

## [v0.2.0] - 2025-12-01

- No changes

## [v0.1.9] - 2025-11-27

## 🔄 Other Changes

- fix cookie auth (#8) @amankumarsingh77

## [v0.1.8] - 2025-11-24

- No changes

## [v0.1.7] - 2025-11-24

- No changes

## [v0.1.6] - 2025-11-24

- No changes

## [v0.1.5] - 2025-11-22

- No changes

## [v0.1.4] - 2025-11-22

- No changes

## [v0.1.3] - 2025-11-22

## 🔄 Other Changes

- :wip: feature to search posts based on a topic (#6) @kgritesh
- Feat/open link (#7) @Hungerarray

## [v0.1.2] - 2025-09-24

- No changes

## [v0.1.1] - 2025-09-24

- No changes

## 🔄 Other Changes

- Refactor/remove relative imports (#3) @amankumarsingh77
- Refact: Rename project and minor changes (#4) @amankumarsingh77
